#
# spec file for package vulkan
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define version_unconverted 1.0.65.0

Name:           vulkan
%define lname	libvulkan1
Version:        1.0.65.0
Release:        150000.5.3.1
Summary:        Vulkan loader and validation layers
License:        MIT
Group:          Development/Libraries/C and C++
Url:            http://www.khronos.org/

Source:         Vulkan-LoaderAndValidationLayers-%version.tar.xz
Source9:        baselibs.conf
BuildRequires:  bison
BuildRequires:  cmake >= 2.8.11
BuildRequires:  gcc-c++ >= 4.8
BuildRequires:  glslang-devel >= 3.0
BuildRequires:  libpciaccess-devel
BuildRequires:  pkg-config
BuildRequires:  python3
BuildRequires:  spirv-tools-devel
BuildRequires:  systemd-devel
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(wayland-cursor)
BuildRequires:  pkgconfig(wayland-egl)
BuildRequires:  pkgconfig(wayland-server)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xcb)
BuildRequires:  pkgconfig(xkbcommon)
BuildRequires:  pkgconfig(xrandr)

%description
Vulkan is a 3D graphics and compute API providing cross-platform
access to modern GPUs with low overhead and targeting realtime
graphics applications such as games and interactive media.

This package contains the reference ICD loader and validation layers
for Vulkan.

%package -n %lname
Summary:        The Vulkan 3D graphics and compute API
# for config files
Group:          System/Libraries
Requires:       %name

%description -n %lname
Vulkan is a 3D graphics and compute API providing cross-platform
access to modern GPUs with low overhead and targeting realtime
graphics applications such as games and interactive media.

%package devel
Summary:        Vulkan development package
Group:          Development/Libraries/C and C++
Requires:       %lname = %version-%release

%description devel
Vulkan is a 3D graphics and compute API providing cross-platform
access to modern GPUs with low overhead and targeting realtime
graphics applications such as games and interactive media.

This subpackage contains the development headers for packages wanting
to make use of Vulkan.

%prep
%setup -qn Vulkan-LoaderAndValidationLayers-%version

%build
chmod a-x *.md *.txt
perl -i -pe 's{inttypes\.h}{cinttypes}g' layers/*.cpp layers/*.h *.py
mkdir -p ../glslang/install/bin ../glslang/build/install
ln -sv /usr/bin/glslangValidator ../glslang/install/bin/
ln -Tsv "%_libdir" ../glslang/build/install/lib
%cmake \
	-DCMAKE_INSTALL_SYSCONFDIR="%_sysconfdir" \
	-DCMAKE_SKIP_RPATH=ON \
	-DBUILD_WSI_MIR_SUPPORT=OFF
make %{?_smp_mflags}

%install
b="%buildroot"
%cmake_install
mkdir -p "$b/%_bindir" "$b/%_includedir" \
	"$b/%_datadir/vulkan/implicit_layer.d" \
	"$b/%_datadir/vulkan/explicit_layer.d" \
	"$b/%_sysconfdir/vulkan/icd.d"
install -pm0755 build/demos/vulkaninfo "$b/%_bindir/vulkaninfo"
cp -a include/vulkan "$b/%_includedir/"
cp -a layers/linux/*.json "$b/%_datadir/vulkan/explicit_layer.d/"
rm -f "$b/%_datadir/vulkan/explicit_layer.d"/*implicit*
for i in "$b/%_datadir/vulkan/explicit_layer.d"/*.json; do
	perl -i -pe 's{"\./lib}{"lib}g' "$i"
done
mkdir -p "$b/%_bindir"
cp -a build/demos/cube "$b/%_bindir/vkcube"
cp -a build/demos/cubepp "$b/%_bindir/vkcubepp"

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files
%defattr(-,root,root)
%_bindir/*
%dir %_sysconfdir/vulkan/
%config %_sysconfdir/vulkan/explicit_layer.d/
%dir %_sysconfdir/vulkan/icd.d/
%_sysconfdir/vulkan/icd.d/*
%_datadir/vulkan/

%files -n libvulkan1
%defattr(-,root,root)
%doc README.md LICENSE.txt
%_libdir/libVkLayer*.so
%_libdir/libvulkan.so.1*

%files devel
%defattr(-,root,root)
%_includedir/vulkan/
%_libdir/libvulkan.so
%_libdir/pkgconfig/vulkan.pc

%changelog
* Mon Apr 11 2022 yfjiang@suse.com
- Disable RPATH to make the inherited package run on SLE-15-SP4
  (bsc#1197862).
* Thu Mar 22 2018 meissner@suse.com
- enable vulkan-devel 32bit in baselibs. (bsc#1086440)
* Wed Jan 10 2018 jengelh@inai.de
- Drop ImageMagick build-time requirement
* Thu Nov 16 2017 jengelh@inai.de
- Update to new snapshot 1.0.65
  * The VK_EXT_global_priority extension extends the concept of
    device-scope queue priorities to now be a system-wide scope.
    The global/system-wide priority level takes priority over the
    per-process queue priorities.
  * New extension VK_KHR_bind_memory2: This extension allows
    vkBindBufferMemory and vkBindImageMemory to support multiple
    bindings to be performed at once while also being more
    extensible.
  * New extension VK_KHR_image_format_list: Provides a list of
    all formats that can be used with a Vulkan image when it is
    created.
  * New extension VK_KHR_maintenance2: Adds in various changes
    that were left out of Vulkan previously. These maintenance
    updates allow implementations to express clipping behavior of
    points, creating images with usage flags that may not be
    supported for the base image's format, creating uncompressed
    image views of compressed images, two new image layouts for
    depth stencil images, and other minor changes.
  * New extension VK_KHR_sampler_ycbcr_conversion: Support to
    perform specified color space conversions during texture
    sampling operations.
- Drop 0001-cmake-GH1444-add-wayland-include-dir-to-cmake.patch
  (included upstream)
* Sat Aug 12 2017 jengelh@inai.de
- Update to new upstream release 1.0.57.0
  * loader: Do not enumerate extensions from disabled implicit
    layers
  * layers:Handle ALL_*_BIT pipe stage barrier validation
  * LVL: Add validation check for CreateImageView
  * loader: Remove executable stack from libvulkan.so
  * layers: Fix mismatched new[] / delete
  * layers: Add new PV ranged enum validation function
  * layers: Don't do bogus transitions in invalidateCommandBuffers
* Mon Aug  7 2017 jengelh@inai.de
- Update to new upstream release 1.0.54
  * Fix a few potential overruns
  * Configurable fallback search paths
  * Validate device features: imageCubeArray, dualSrcBlend,
    multiDrawIndirect, depthClamp, depthBounds, alphaToOne,
    samplerAnisotropy.
  * Add compressed texture query utils
  * Add feature checks for textureCompressionETC2,
    textureCompressionASTC_LDR, textureCompressionBC,
    sparseBinding device, sparseResidencyBuffer,
    sparseResidencyAliased, depthBiasClamp.
  * Remove deprecated KHX extension from OT/PV
  * Support CapabilityGeometryShaderPassThroughNV and
    CapabilitySampleMaskOverrideCoverage.
  * Support the viewport_array2, shader_subgroup_ballot and
    shader_subgroup_vote ext shader caps.
  * Change size of X8_D24_UNORM_PACK32 and D32_SFLOAT_S8_UINT
- Add 0001-cmake-GH1444-add-wayland-include-dir-to-cmake.patch
* Mon Feb 20 2017 jengelh@inai.de
- Update to new upstream release 1.0.41
  * layers: Move image struct into cv_types header
  * layers: Move CreateImage validation into core_val
  * layers: Move DestroyImage code into buffer module
  * layers: Move CreateRenderPass format check to PV
  * layers: Rename misleading renderpass structure var
  * layers:Move gfx pipe check to create time
  * layers: Move image validation support to buffer_val
  * layers: Add enable for NV_GLSL_SHADER extension
- Add baselibs.conf [needed by libgtk-4-0]
* Mon Jan 30 2017 jengelh@inai.de
- Update to new upstream release 1.0.39.1
  * layers: Add tracking for VK_KHR_display extension in PV
  * layers: Add null checks to RetireWorkOnQueue
  * vulkaninfo: fix segfault when DISPLAY is not set
  * layers: Complete support for VK_KHR_Display ext
* Mon Oct 31 2016 jengelh@inai.de
- Update to 1.0.32.g28
  * vkjson: Rename VkJsonAllProperties to VkJsonDevice
  * loader: Fix json output of escape chars
  * loader: Fix segfault in vulkaninfo
  * Add vulkan C++ header
- Remove 0001-layers-Install-to-CMAKE_INSTALL_LIBDIR.patch,
  0001-loader-Add-install-rule.patch,
  0001-vkjson-don-t-clobber-cflags-or-you-ll-lose-fPIC.patch
  (upstreamed).
* Mon Jun 13 2016 jengelh@inai.de
- Update to new snapshot 1.0.3.g5493
  * Added helpers: getSwapchainNode(), getSwapchainFromImage(),
  getImageNode(), getImageViewData(), getSamplerNode(),
  getBufferViewInfo(), getBufferNode().
- Resolve build failure stemming from new glslang version
- Add 0001-layers-Install-to-CMAKE_INSTALL_LIBDIR.patch,
  0001-loader-Add-install-rule.patch,
  0001-vkjson-don-t-clobber-cflags-or-you-ll-lose-fPIC.patch.
  These were in a prior tarball made from a Fedora git,
  but we since switched to the upstream git.
* Wed Feb 17 2016 jengelh@inai.de
- Initial package (version 1.0.3.g19) for build.opensuse.org
